@@ -25,7 +25,7 @@ G_BEGIN_DECLS
 
 #include <glib.h>
 #include "gst-tool.h"
-#include <oobs/oobs-smbconfig.h>
+#include <oobs/oobs.h>
 
 #define GST_TYPE_SHARES_TOOL         (gst_shares_tool_get_type())
 #define GST_SHARES_TOOL(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), GST_TYPE_SHARES_TOOL, GstSharesTool))
@@ -46,10 +46,12 @@ struct _GstSharesTool {
 	/* read only */
 	OobsObject *services_config;
 	OobsObject *hosts_config;
-	OobsObject *ifaces_config;
+	OobsObject *users_config;
 
-	gboolean smb_available : 1;
-	gboolean nfs_available : 1;
+	gchar *path;
+
+	guint smb_available : 1;
+	guint nfs_available : 1;
 };
 
 struct _GstSharesToolClass {
