@@ -144,7 +144,7 @@ check_user_delete (OobsUser *user)
 	g_object_unref (admin_group);
 	g_list_free (admin_users);
 
-	/* Home flag is used to remove home when deleting an user */
+	/* Home flag is used to remove home when deleting a user */
 	if (response == GTK_RESPONSE_YES)
 		oobs_user_set_home_flags (user, OOBS_USER_REMOVE_HOME);
 	else
@@ -342,7 +342,7 @@ user_settings_show (OobsUser *user)
 	if (oobs_user_get_password_empty (user))
 		/* TRANSLATORS: This applies to a password. */
 		gtk_label_set_text (GTK_LABEL (passwd_label), _("None"));
-	else if (oobs_user_is_in_group (user, group))
+	else if (group && oobs_user_is_in_group (user, group))
 		/* TRANSLATORS:  This applies to a password. Keep the string short. */
 		gtk_label_set_text (GTK_LABEL (passwd_label), _("Not asked on login"));
 	else
@@ -493,7 +493,7 @@ check_shell (gchar **primary_text, gchar **secondary_text, gpointer data)
 	const gchar *path;
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_shell");
-	path = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (widget)->child));
+	path = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (widget))));
 
 	if (strlen (path) < 1 || !g_path_is_absolute (path)) {
 		*primary_text = g_strdup (_("Incomplete path in shell"));
@@ -930,6 +930,8 @@ on_user_new (GtkButton *button, gpointer user_data)
 	/* Show the encrypt home check box if supported */
 	if (oobs_users_config_get_encrypted_home_support (users_config))
 	    gtk_widget_show (encrypted_home);
+	else
+	    gtk_widget_hide (encrypted_home);
 
 	gtk_window_set_focus (GTK_WINDOW (user_new_dialog), user_name);
 
@@ -1053,6 +1055,7 @@ on_edit_user_name (GtkButton *button, gpointer user_data)
 	OobsUser *user;
 	const char *fullname;
 	gboolean is_self;
+	OobsResult result;
 
 	user = users_table_get_current ();
 
@@ -1090,12 +1093,14 @@ on_edit_user_name (GtkButton *button, gpointer user_data)
 		oobs_user_set_full_name (user, fullname);
 
 		if (is_self)
-			gst_tool_commit (tool, GST_USERS_TOOL (tool)->self_config);
+			result = gst_tool_commit (tool, GST_USERS_TOOL (tool)->self_config);
 		else
-			gst_tool_commit (tool, OOBS_OBJECT (user));
+			result = gst_tool_commit (tool, OOBS_OBJECT (user));
 
-		gtk_label_set_text (GTK_LABEL (user_settings_real_name), fullname);
-		users_table_update_current ();
+		if (result == OOBS_RESULT_OK) {
+			gtk_label_set_text (GTK_LABEL (user_settings_real_name), fullname);
+			users_table_update_current ();
+		}
 	}
 
 	g_object_unref (user);
@@ -1228,7 +1233,7 @@ on_edit_user_advanced (GtkButton *button, gpointer user_data)
 	set_entry_text (widget, (user) ? oobs_user_get_home_phone_number (user) : NULL);
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_shell");
-	set_entry_text (GTK_BIN (widget)->child, oobs_user_get_shell (user));
+	set_entry_text (gtk_bin_get_child (GTK_BIN (widget)), oobs_user_get_shell (user));
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_home");
 	set_entry_text (widget, oobs_user_get_home_directory (user));
@@ -1284,7 +1289,7 @@ on_edit_user_advanced (GtkButton *button, gpointer user_data)
 	oobs_user_set_home_phone_number (user, gtk_entry_get_text (GTK_ENTRY (widget)));
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_shell");
-	oobs_user_set_shell (user, gtk_entry_get_text (GTK_ENTRY (GTK_BIN (widget)->child)));
+	oobs_user_set_shell (user, gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (widget)))));
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_home");
 	oobs_user_set_home_directory (user, gtk_entry_get_text (GTK_ENTRY (widget)));
